trigger property

Object? trigger
final

The value used to trigger the animation. As long as the value of trigger is the same, the animation will not be triggered again.

The sentinel #immediate plays the animation as soon as it mounts, once per State lifetime.

Implementation

final Object? trigger;