ScrollTransition class

A widget that applies a set of effects to its child based on the current phase and position of the scroll position of the parent scrollable widget.

Inheritance
Available extensions

Constructors

ScrollTransition({Key? key, required Widget child, ScrollTransitionBuilder? builder, bool usePointerRouter = true})
Creates a new ScrollTransition with the given builder and child.
const

Properties

builder → ScrollTransitionBuilder?
A function that builds a widget based on the current phase of the scroll animation.
final
child → Widget
The child widget to apply the effects to.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
usePointerRouter → bool
Whether this transition should rely on WidgetsBinding.instance.pointerRouter.addGlobalRoute to read the pointer device's position, which is useful for reading cursor events that may not be read properly via MouseRegions like if the cursor is outside the bounds of the physical window or applies some unusual gesture that may not be normally detected.
final

Methods

align(AlignmentGeometry alignment, {AlignmentGeometry? from, double? heightFactor, double? widthFactor, double? fromHeightFactor, double? fromWidthFactor}) → Widget

Available on Widget, provided by the AlignEffectExt extension

Applies an AlignEffect to a Widget with the given alignment, optionally animating from from.
alignX(double x, {double? from}) → Widget

Available on Widget, provided by the AlignEffectExt extension

Applies an AlignEffect to a Widget only on the x-axis.
alignXY(double x, double y, {AlignmentGeometry? from}) → Widget

Available on Widget, provided by the AlignEffectExt extension

Applies an AlignEffect to a Widget with the given x and y values.
alignY(double y, {double? from}) → Widget

Available on Widget, provided by the AlignEffectExt extension

Applies an AlignEffect to a Widget only on the y-axis.
animate({required Object? trigger, Key? key, Duration? duration, Curve? curve, Motion? motion, int repeat = 0, bool reverse = false, bool resetValues = false, bool interruptable = true, Duration delay = Duration.zero, AnimationStartState startState = AnimationStartState.lazy, VoidCallback? onEnd, BooleanCallback? playIf, BooleanCallback? skipIf, AnimationBehavior? animationBehavior}) → Widget

Available on Widget?, provided by the AnimatedEffectExt extension

Animate the effects applied to this widget.
blur(double blur, {double? from}) → Widget

Available on Widget, provided by the BlurEffectExt extension

Applies a BlurEffect to this widget with given blur value.
blurIn({double blur = 10, double? end}) → Widget

Available on Widget, provided by the BlurEffectExt extension

Applies a BlurEffect to this widget with a default blur in animation.
blurOut({double blur = 10, double? start}) → Widget

Available on Widget, provided by the BlurEffectExt extension

Applies a BlurEffect to this widget with a default blur out animation.
blurX(double blurX, {double? from}) → Widget

Available on Widget, provided by the BlurEffectExt extension

Applies a BlurEffect to only the horizontal axis of this widget with given blurX value.
blurXY(double blurX, double blurY, {Offset? from}) → Widget

Available on Widget, provided by the BlurEffectExt extension

Applies a BlurEffect to this widget with given blurX and blurY values.
blurY(double blurY, {double? from}) → Widget

Available on Widget, provided by the BlurEffectExt extension

Applies a BlurEffect to only the vertical axis of this widget with given blurY value.
clip(double radius, {Clip? clip, double? from}) → Widget

Available on Widget, provided by the ClipEffectExtension extension

Applies an ClipEffect to a Widget with the given clip and radius.
clipCorners(List<double> corners, {Clip? clip, List<double>? from}) → Widget

Available on Widget, provided by the ClipEffectExtension extension

Applies an ClipEffect to a Widget with the given clip and a corners.
clipRRect(BorderRadius borderRadius, {Clip? clip, BorderRadius? from}) → Widget

Available on Widget, provided by the ClipEffectExtension extension

Applies an ClipEffect to a Widget with the given clip and a borderRadius.
color({Color? color, BlendMode mode = BlendMode.overlay, List<double>? matrix, Color? colorFrom, List<double>? fromMatrix}) → Widget

Available on Widget, provided by the ColorFilterEffectExtension extension

Applies an ColorFilterEffect to a Widget.
createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<ScrollTransition>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
fade(double opacity, {double? from}) → Widget

Available on Widget, provided by the OpacityEffectExtension extension

Alias to opacity.
fadeIn({double start = 0, double end = 1}) → Widget

Available on Widget, provided by the OpacityEffectExtension extension

Applies an OpacityEffect to a Widget with a default fade in animation.
fadeOut({double start = 1, double end = 0}) → Widget

Available on Widget, provided by the OpacityEffectExtension extension

Applies an OpacityEffect to a Widget with a default fade out animation.
heightTo(double height, {double? from}) → Widget

Available on Widget, provided by the SizeEffectExt extension

Applies a SizeEffect that constrains this Widget's height to height, leaving its width unconstrained, optionally animating from from.
immediate({Key? key, Duration? duration, Curve? curve, Motion? motion, int repeat = 0, bool reverse = false, bool resetValues = false, bool interruptable = true, Duration delay = Duration.zero, VoidCallback? onEnd, BooleanCallback? playIf, BooleanCallback? skipIf, AnimationBehavior? animationBehavior}) → AnimatedEffect

Available on Widget?, provided by the AnimatedEffectExt extension

Animate the effects applied to this widget.
modulate({Color? color, BlendMode mode = BlendMode.overlay, List<double>? matrix, Color? colorFrom, List<double>? fromMatrix}) → Widget

Available on Widget, provided by the ColorFilterEffectExtension extension

Applies an ColorFilterEffect to a Widget.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
opacity(double opacity, {double? from}) → Widget

Available on Widget, provided by the OpacityEffectExtension extension

Applies an OpacityEffect to a Widget.
pad(EdgeInsets padding, {EdgeInsets? from}) → Widget

Available on Widget, provided by the PaddingEffectExt extension

Applies an PaddingEffect to a Widget with the given padding.
padAll(double padding, {double? from}) → Widget

Available on Widget, provided by the PaddingEffectExt extension

Applies an PaddingEffect to a Widget with the given padding.
padBottom(double padding, {double? from}) → Widget

Available on Widget, provided by the PaddingEffectExt extension

Applies an PaddingEffect to a Widget with the given bottom padding.
padHorizontal(double padding, {double? from}) → Widget

Available on Widget, provided by the PaddingEffectExt extension

Applies an PaddingEffect to a Widget with the given horizontal padding.
padLeft(double padding, {double? from}) → Widget

Available on Widget, provided by the PaddingEffectExt extension

Applies an PaddingEffect to a Widget with the given left padding.
padOnly({double left = 0, double right = 0, double top = 0, double bottom = 0, double? from}) → Widget

Available on Widget, provided by the PaddingEffectExt extension

Applies an PaddingEffect to a Widget with the given left, right, top, and bottom padding.
padRight(double padding, {double? from}) → Widget

Available on Widget, provided by the PaddingEffectExt extension

Applies an PaddingEffect to a Widget with the given right padding.
padSymmetric({double vertical = 0, double horizontal = 0, double? from}) → Widget

Available on Widget, provided by the PaddingEffectExt extension

Applies an PaddingEffect to a Widget with the given vertical and horizontal padding.
padTop(double padding, {double? from}) → Widget

Available on Widget, provided by the PaddingEffectExt extension

Applies an PaddingEffect to a Widget with the given top padding.
padVertical(double padding, {double? from}) → Widget

Available on Widget, provided by the PaddingEffectExt extension

Applies an PaddingEffect to a Widget with the given vertical padding.
pointerTransition(PointerTransitionBuilder builder, {Alignment origin = Alignment.center, bool useGlobalPointer = false, bool usePointerRouter = true, bool transitionBetweenBounds = true, bool resetOnExitBounds = true, Curve curve = appleEaseInOut, Duration duration = const Duration(milliseconds: 125), Key? key, AnimationBehavior? animationBehavior}) → Widget

Available on Widget, provided by the PointerTransitionExt extension

Applies pointer transition effects to this widget.
resetAll() → Widget

Available on Widget?, provided by the AnimatedEffectExt extension

Resets all animations in the chain by going down the children tree and resetting all animations.
roll({AxisDirection slideInDirection = AxisDirection.up, AxisDirection slideOutDirection = AxisDirection.up, double multiplier = 1, bool useSnapshots = false}) → EffectWidget

Available on Widget?, provided by the RollEffectExtension extension

Applies an RollEffect to a Widget with the given slideInDirection, slideOutDirection and multiplier.
rotate(double angle, {Offset origin = Offset.zero, AlignmentGeometry alignment = Alignment.center, double? from}) → Widget

Available on Widget, provided by the RotationEffectExt extension

Applies a RotationEffect to a Widget.
rotateIn({double? from, Offset origin = Offset.zero, AlignmentGeometry alignment = Alignment.center}) → Widget

Available on Widget, provided by the RotationEffectExt extension

Applies a RotationEffect to a Widget to rotate it in.
rotateOut({double? to, Offset origin = Offset.zero, AlignmentGeometry alignment = Alignment.center}) → Widget

Available on Widget, provided by the RotationEffectExt extension

Applies a RotationEffect to a Widget to rotate it out.
scale(double scale, {AlignmentGeometry alignment = Alignment.center, Offset origin = Offset.zero, double? from, bool transformHitTests = true}) → Widget

Available on Widget, provided by the ScaleEffectExt extension

Applies a ScaleEffect to a Widget with the given scale on both axes.
scaleIn({double? start, double? end, AlignmentGeometry alignment = Alignment.center, Offset origin = Offset.zero, bool transformHitTests = true}) → Widget

Available on Widget, provided by the ScaleEffectExt extension

Applies an ScaleEffect to a Widget with a default scale in animation.
scaleOut({double? start, double? end, AlignmentGeometry alignment = Alignment.center, Offset origin = Offset.zero, bool transformHitTests = true}) → Widget

Available on Widget, provided by the ScaleEffectExt extension

Applies an ScaleEffect to a Widget with a default scale out animation.
scaleX(double scaleX, {AlignmentGeometry alignment = Alignment.center, Offset origin = Offset.zero, double? from, bool transformHitTests = true}) → Widget

Available on Widget, provided by the ScaleEffectExt extension

Applies a ScaleEffect to a Widget only on the x-axis.
scaleXY(double scaleX, double scaleY, {AlignmentGeometry alignment = Alignment.center, Offset origin = Offset.zero, Offset? from, bool transformHitTests = true}) → Widget

Available on Widget, provided by the ScaleEffectExt extension

Applies a ScaleEffect to a Widget with the given scaleX and scaleY.
scaleY(double scaleY, {AlignmentGeometry alignment = Alignment.center, Offset origin = Offset.zero, double? from, bool transformHitTests = true}) → Widget

Available on Widget, provided by the ScaleEffectExt extension

Applies a ScaleEffect to a Widget only on the y-axis.
scrollTransition(ScrollTransitionBuilder builder) → Widget

Available on Widget, provided by the ScrollTransitionExt extension

Applies scroll transition effects to this widget.
shake({double frequency = 8, Offset offset = const Offset(5, 0), double rotation = pi / 36}) → Widget

Available on Widget, provided by the ShakeEffectExt extension

Applies a ShakeEffect to a Widget.
sizeOf({double? width, double? height, double? fromWidth, double? fromHeight}) → Widget

Available on Widget, provided by the SizeEffectExt extension

Applies a SizeEffect with independently nullable width and height, each with its own optional starting value.
sizeTo(Size size, {Size? from}) → Widget

Available on Widget, provided by the SizeEffectExt extension

Applies a SizeEffect that constrains this Widget to size, optionally animating from from.
skew(double skew, {AlignmentGeometry alignment = Alignment.center, Offset origin = Offset.zero, double skewFrom = 0, AlignmentGeometry alignmentFrom = Alignment.center, Offset originFrom = Offset.zero}) → Widget

Available on Widget, provided by the SkewEffectExt extension

Applies a SkewEffect to a Widget with the given skew on both axes.
skewX(double skewX, {AlignmentGeometry alignment = Alignment.center, Offset origin = Offset.zero, double skewFrom = 0, AlignmentGeometry alignmentFrom = Alignment.center, Offset originFrom = Offset.zero}) → Widget

Available on Widget, provided by the SkewEffectExt extension

Applies a SkewEffect to a Widget only on the x-axis.
skewXY(double skewX, double skewY, {AlignmentGeometry alignment = Alignment.center, Offset origin = Offset.zero, double skewFromX = 0, double skewFromY = 0, AlignmentGeometry alignmentFrom = Alignment.center, Offset originFrom = Offset.zero}) → Widget

Available on Widget, provided by the SkewEffectExt extension

Applies a SkewEffect to a Widget with the given skewX and skewY.
skewY(double skewY, {AlignmentGeometry alignment = Alignment.center, Offset origin = Offset.zero, double skewFrom = 0, AlignmentGeometry alignmentFrom = Alignment.center, Offset originFrom = Offset.zero}) → Widget

Available on Widget, provided by the SkewEffectExt extension

Applies a SkewEffect to a Widget only on the y-axis.
slideIn(Offset offset, {bool fractional = false, bool transformHitTests = true}) → Widget

Available on Widget, provided by the TranslateEffectExt extension

Applies a TranslateEffect to a Widget with a default animation to slide this widget in.
slideInFromBottom({double? value, bool fractional = false, bool transformHitTests = true}) → Widget

Available on Widget, provided by the TranslateEffectExt extension

Applies a TranslateEffect to a Widget with a default animation to slide this widget in from the bottom.
slideInFromLeft({double? value, bool fractional = false, bool transformHitTests = true}) → Widget

Available on Widget, provided by the TranslateEffectExt extension

Applies a TranslateEffect to a Widget with a default animation to slide this widget in from the right.
slideInFromRight({double? value, bool fractional = false, bool transformHitTests = true}) → Widget

Available on Widget, provided by the TranslateEffectExt extension

Applies a TranslateEffect to a Widget with a default animation to slide this widget in from the right.
slideInFromTop({double? value, bool fractional = false, bool transformHitTests = true}) → Widget

Available on Widget, provided by the TranslateEffectExt extension

Applies a TranslateEffect to a Widget with a default animation to slide this widget in from the top.
slideInHorizontally(double x, {bool fractional = false, bool transformHitTests = true}) → Widget

Available on Widget, provided by the TranslateEffectExt extension

Applies a TranslateEffect to a Widget with a default animation to slide this widget in.
slideInVertically(double y, {bool fractional = false, bool transformHitTests = true}) → Widget

Available on Widget, provided by the TranslateEffectExt extension

Applies a TranslateEffect to a Widget with a default animation to slide this widget in.
slideOut(Offset offset, {bool fractional = false, bool transformHitTests = true}) → Widget

Available on Widget, provided by the TranslateEffectExt extension

Applies a TranslateEffect to a Widget with a default animation to slide this widget out.
slideOutHorizontally(double x, {bool fractional = false, bool transformHitTests = true}) → Widget

Available on Widget, provided by the TranslateEffectExt extension

Applies a TranslateEffect to a Widget with a default animation to slide this widget out.
slideOutToBottom({double? value, bool fractional = false, bool transformHitTests = true}) → Widget

Available on Widget, provided by the TranslateEffectExt extension

Applies a TranslateEffect to a Widget with a default animation to slide this widget out to the bottom.
slideOutToLeft({double? value, bool fractional = false, bool transformHitTests = true}) → Widget

Available on Widget, provided by the TranslateEffectExt extension

Applies a TranslateEffect to a Widget with a default animation to slide this widget out to the left.
slideOutToRight({double? value, bool fractional = false, bool transformHitTests = true}) → Widget

Available on Widget, provided by the TranslateEffectExt extension

Applies a TranslateEffect to a Widget with a default animation to slide this widget out to the right.
slideOutToTop({double? value, bool fractional = false, bool transformHitTests = true}) → Widget

Available on Widget, provided by the TranslateEffectExt extension

Applies a TranslateEffect to a Widget with a default animation to slide this widget out to the top.
slideOutVertically(double y, {bool fractional = false, bool transformHitTests = true}) → Widget

Available on Widget, provided by the TranslateEffectExt extension

Applies a TranslateEffect to a Widget with a default animation to slide this widget out.
step({Duration? duration, Curve? curve, Motion? motion, Duration delay = Duration.zero}) → Widget

Available on Widget, provided by the TimelineChainExt extension

Marks the boundary between two keyframes of a timeline chain.
timeline({Object? trigger, TimelineController? controller, VoidCallback? onEnd, int repeat = 0}) → Widget

Available on Widget, provided by the TimelineEffectExt extension

Compiles the effect/TimelineChainExt.step chain this is called on into a single-controller timeline and plays it on trigger changes.
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
transform({double translateX = 0, double translateY = 0, double translateZ = 0, double rotateX = 0, double rotateY = 0, double rotateZ = 0, double scaleX = 1, double scaleY = 1, double scaleZ = 1, double depth = 0, AlignmentGeometry alignment = Alignment.center, Offset origin = Offset.zero}) → Widget

Available on Widget, provided by the TransformEffectExt extension

Applies a TransformEffect to a Widget.
translate(Offset offset, {bool fractional = false, bool transformHitTests = true, Offset? from}) → Widget

Available on Widget, provided by the TranslateEffectExt extension

Applies a TranslateEffect to a Widget with the given offset. fractional determines whether the offset moves the Widget by using its own size as a percentage or by a fixed amount. transformHitTests matches Flutter's Transform.translate default: hit testing follows the painted widget. Pass false only for deliberately paint-only movement whose interactive region must stay in layout space.
translateX(double x, {bool fractional = false, bool transformHitTests = true, double? from}) → Widget

Available on Widget, provided by the TranslateEffectExt extension

Applies a TranslateEffect to a Widget only on the x-axis. fractional determines whether the offset moves the Widget by using its own size as a percentage or by a fixed amount.
translateXY(double x, double y, {bool fractional = false, bool transformHitTests = true, Offset? from}) → Widget

Available on Widget, provided by the TranslateEffectExt extension

Applies a TranslateEffect to a Widget with the given x and y values. fractional determines whether the offset moves the Widget by using its own size as a percentage or by a fixed amount.
translateY(double y, {bool fractional = false, bool transformHitTests = true, double? from}) → Widget

Available on Widget, provided by the TranslateEffectExt extension

Applies a TranslateEffect to a Widget only on the y-axis. fractional determines whether the offset moves the Widget by using its own size as a percentage or by a fixed amount.
widthTo(double width, {double? from}) → Widget

Available on Widget, provided by the SizeEffectExt extension

Applies a SizeEffect that constrains this Widget's width to width, leaving its height unconstrained, optionally animating from from.

Operators

operator ==(Object other) → bool
The equality operator.
inherited